@@ -1,4 +1,4 @@
-/* $Id: browser.c,v 1.113 2006/11/10 02:47:11 dolorous Exp $ */
+/* $Id: browser.c,v 1.116 2006/12/11 22:11:32 dolorous Exp $ */
 /**************************************************************************
  *   browser.c                                                            *
  *                                                                        *
@@ -203,11 +203,11 @@ char *do_browser(char *path, DIR *dir)
 		if (selected > filelist_len - 1)
 		    selected = filelist_len - 1;
 		break;
-	    case NANO_FIRSTFILE_ALTKEY:
+	    case NANO_FIRSTFILE_METAKEY:
 		if (meta_key)
 		    selected = 0;
 		break;
-	    case NANO_LASTFILE_ALTKEY:
+	    case NANO_LASTFILE_METAKEY:
 		if (meta_key)
 		    selected = filelist_len - 1;
 		break;
@@ -231,7 +231,9 @@ char *do_browser(char *path, DIR *dir)
 #endif
 		bottombars(browser_list);
 
-		if (i < 0) {
+		/* If the directory begins with a newline (i.e. an
+		 * encoded null), treat it as though it's blank. */
+		if (i < 0 || answer[0] == '\n') {
 		    /* We canceled.  Indicate that on the statusbar, and
 		     * blank out ans, since we're done with it. */
 		    statusbar(_("Cancelled"));
@@ -251,6 +253,11 @@ char *do_browser(char *path, DIR *dir)
 		 * with it. */
 		ans = mallocstrcpy(ans, "");
 
+		/* Convert newlines to nulls, just before we go to the
+		 * directory. */
+		sunder(answer);
+		align(&answer);
+
 		new_path = real_dir_from_tilde(answer);
 
 		if (new_path[0] != '/') {
@@ -621,19 +628,20 @@ void browser_refresh(void)
 		/* The length of the file information in columns. */
 	int foomaxlen = 7;
 		/* The maximum length of the file information in
-		 * columns: 7 for "--", "(dir)", or the file size, and
-		 * 12 for "(parent dir)". */
+		 * columns: seven for "--", "(dir)", or the file size,
+		 * and 12 for "(parent dir)". */
 	bool dots = (COLS >= 15 && filetaillen >= longest -
 		foomaxlen - 1);
 		/* Do we put an ellipsis before the filename?  Don't set
-		 * this to TRUE if we have fewer than 15 columns (i.e. 1
-		 * column for padding, plus 7 columns for a filename
-		 * other than ".."). */
+		 * this to TRUE if we have fewer than 15 columns (i.e.
+		 * one column for padding, plus seven columns for a
+		 * filename other than ".."). */
 	char *disp = display_string(filetail, dots ? filetaillen -
 		longest + foomaxlen + 4 : 0, longest, FALSE);
-		/* If we put an ellipsis before the filename, reserve 1
-		 * column for padding, plus 7 columns for "--", "(dir)",
-		 * or the file size, plus 3 columns for the ellipsis. */
+		/* If we put an ellipsis before the filename, reserve
+		 * one column for padding, plus seven columns for "--",
+		 * "(dir)", or the file size, plus three columns for the
+		 * ellipsis. */
 
 	/* Start highlighting the currently selected file or
 	 * directory. */
