@@ -1,4 +1,4 @@
-/* $Id: files.c,v 1.322 2006/11/10 02:47:11 dolorous Exp $ */
+/* $Id: files.c,v 1.340 2006/12/15 05:03:08 dolorous Exp $ */
 /**************************************************************************
  *   files.c                                                              *
  *                                                                        *
@@ -132,8 +132,8 @@ void open_buffer(const char *filename)
     if (new_buffer)
 	make_new_buffer();
 
-    /* If we have a file and we're loading into a new buffer, update the
-     * filename. */
+    /* If we have a file, and we're loading into a new buffer, update
+     * the filename. */
     if (rc != -1 && new_buffer)
 	openfile->filename = mallocstrcpy(openfile->filename, filename);
 
@@ -150,7 +150,7 @@ void open_buffer(const char *filename)
 #endif
     }
 
-    /* If we have a file and we're loading into a new buffer, move back
+    /* If we have a file, and we're loading into a new buffer, move back
      * to the beginning of the first line of the buffer. */
     if (rc != -1 && new_buffer) {
 	openfile->current = openfile->fileage;
@@ -294,8 +294,8 @@ filestruct *read_line(char *buf, filestruct *prevnode, bool
 {
     filestruct *fileptr = (filestruct *)nmalloc(sizeof(filestruct));
 
-    /* Convert nulls to newlines.  buf_len is the string's real length
-     * here. */
+    /* Convert nulls to newlines.  buf_len is the string's real
+     * length. */
     unsunder(buf, buf_len);
 
     assert(openfile->fileage != NULL && strlen(buf) == buf_len);
@@ -728,8 +728,10 @@ void do_insertfile(
 		"./");
 
 	/* If we're in multibuffer mode and the filename or command is
-	 * blank, open a new buffer instead of canceling. */
-	if (i == -1 || (i == -2
+	 * blank, open a new buffer instead of canceling.  If the
+	 * filename or command begins with a newline (i.e. an encoded
+	 * null), treat it as though it's blank. */
+	if (i == -1 || ((i == -2 || answer[0] == '\n')
 #ifdef ENABLE_MULTIBUFFER
 		&& !ISSET(MULTIBUFFER)
 #endif
@@ -800,6 +802,11 @@ void do_insertfile(
 	    }
 #endif
 
+	    /* Convert newlines to nulls, just before we insert the file
+	     * or execute the command. */
+	    sunder(answer);
+	    align(&answer);
+
 #ifndef NANO_TINY
 	    if (execute) {
 #ifdef ENABLE_MULTIBUFFER
@@ -1564,12 +1571,13 @@ int write_file(const char *name, FILE *f_open, bool tmp, append_type
     while (fileptr != NULL) {
 	size_t data_len = strlen(fileptr->data), size;
 
-	/* Newlines to nulls, just before we write to disk. */
+	/* Convert newlines to nulls, just before we write to disk. */
 	sunder(fileptr->data);
 
 	size = fwrite(fileptr->data, sizeof(char), data_len, f);
 
-	/* Nulls to newlines; data_len is the string's real length. */
+	/* Convert nulls to newlines.  data_len is the string's real
+	 * length. */
 	unsunder(fileptr->data, data_len);
 
 	if (size < data_len) {
@@ -1682,7 +1690,8 @@ int write_file(const char *name, FILE *f_open, bool tmp, append_type
 
   cleanup_and_exit:
     free(realname);
-    free(tempname);
+    if (tempname != NULL)
+	free(tempname);
 
     return retval;
 }
@@ -1807,7 +1816,9 @@ int do_writeout(bool exiting)
 #endif
 		);
 
-	if (i < 0) {
+	/* If the filename or command begins with a newline (i.e. an
+	 * encoded null), treat it as though it's blank. */
+	if (i < 0 || answer[0] == '\n') {
 	    statusbar(_("Cancelled"));
 	    retval = -1;
 	    break;
@@ -1869,17 +1880,30 @@ int do_writeout(bool exiting)
 #endif
 
 	    if (append == OVERWRITE) {
-		char *full_answer = get_full_path(answer);
-		char *full_filename = get_full_path(openfile->filename);
-		bool different_name = (strcmp(full_answer,
-			full_filename) != 0);
+		size_t answer_len = strlen(answer);
+		bool name_exists, different_name;
+		char *full_answer, *full_filename;
 		struct stat st;
-		bool name_exists;
 
-		free(full_filename);
-		free(full_answer);
+		/* Convert newlines to nulls, just before we get the
+		 * full path. */
+		sunder(answer);
 
 		name_exists = (stat(answer, &st) != -1);
+		full_answer = get_full_path(answer);
+		full_filename = get_full_path(openfile->filename);
+		different_name = (strcmp((full_answer == NULL) ?
+			answer : full_answer, (full_filename == NULL) ?
+			openfile->filename : full_filename) != 0);
+
+		/* Convert nulls to newlines.  answer_len is the
+		 * string's real length. */
+		unsunder(answer, answer_len);
+
+		if (full_filename != NULL)
+		    free(full_filename);
+		if (full_answer != NULL)
+		    free(full_answer);
 
 		if (different_name) {
 		    if (name_exists) {
@@ -1911,6 +1935,11 @@ int do_writeout(bool exiting)
 		}
 	    }
 
+	    /* Convert newlines to nulls, just before we save the
+	     * file. */
+	    sunder(answer);
+	    align(&answer);
+
 #ifndef NANO_TINY
 	    /* Here's where we allow the selected text to be written to
 	     * a separate file.  If we're using restricted mode, this is
@@ -2381,8 +2410,9 @@ const char *tail(const char *foo)
 }
 
 #if !defined(NANO_TINY) && defined(ENABLE_NANORC)
-/* Return $HOME/.nano_history, or NULL if we can't find the homedir.
- * The string is dynamically allocated, and should be freed. */
+/* Return $HOME/.nano_history, or NULL if we can't find the home
+ * directory.  The string is dynamically allocated, and should be
+ * freed. */
 char *histfilename(void)
 {
     char *nanohist = NULL;
@@ -2419,9 +2449,9 @@ void load_history(void)
 		    ;
 	    }
 	} else {
-	    /* Load a history (first the search history, then the
-	     * replace history) from oldest to newest.  Assume the last
-	     * history entry is a blank line. */
+	    /* Load a history list (first the search history, then the
+	     * replace history) from the oldest entry to the newest.
+	     * Assume the last history entry is a blank line. */
 	    filestruct **history = &search_history;
 	    char *line = NULL;
 	    size_t buflen = 0;
@@ -2453,8 +2483,8 @@ bool writehist(FILE *hist, filestruct *h)
 {
     filestruct *p;
 
-    /* Write history from oldest to newest.  Assume the last history
-     * entry is a blank line. */
+    /* Write a history list from the oldest entry to the newest.  Assume
+     * the last history entry is a blank line. */
     for (p = h; p != NULL; p = p->next) {
 	size_t p_len = strlen(p->data);
 
