@@ -1,4 +1,4 @@
-/* $Id: help.c,v 1.54 2006/11/10 02:47:11 dolorous Exp $ */
+/* $Id: help.c,v 1.57 2006/11/25 22:27:22 dolorous Exp $ */
 /**************************************************************************
  *   help.c                                                               *
  *                                                                        *
@@ -159,11 +159,11 @@ void do_help(void (*refresh_func)(void))
 		if (line + (editwinrows - 1) < last_line)
 		    line++;
 		break;
-	    case NANO_FIRSTLINE_ALTKEY:
+	    case NANO_FIRSTLINE_METAKEY:
 		if (meta_key)
 		    line = 0;
 		break;
-	    case NANO_LASTLINE_ALTKEY:
+	    case NANO_LASTLINE_METAKEY:
 		if (meta_key) {
 		    if (line + (editwinrows - 1) < last_line)
 			line = last_line - (editwinrows - 1);
@@ -493,7 +493,7 @@ void help_init(void)
 	    }
 	    /* Yucky sentinel values that we can't handle a better
 	     * way. */
-	    if (s->metaval == NANO_ALT_SPACE && entries == 1) {
+	    if (s->metaval == NANO_META_SPACE && entries == 1) {
 		char *space_ptr = display_string(_("Space"), 0, 13,
 			FALSE);
 
@@ -609,8 +609,8 @@ size_t help_line_len(const char *ptr)
     while (*(ptr + retval) != '\0' && *(ptr + retval) != '\n')
 	retval += move_mbright(ptr + retval, 0);
 
-    /* If the entire line doesn't go more than 1 column beyond where we
-     * tried to break it, we should display it as-is.  Otherwise, we
+    /* If the entire line doesn't go more than one column beyond where
+     * we tried to break it, we should display it as-is.  Otherwise, we
      * should display it only up to the break. */
     if (strnlenpt(ptr, retval) > help_cols + 1)
 	retval = retval_save;
