@@ -1,4 +1,4 @@
-/* $Id: search.c,v 1.192 2006/11/10 02:47:11 dolorous Exp $ */
+/* $Id: search.c,v 1.193 2006/12/13 00:27:45 dolorous Exp $ */
 /**************************************************************************
  *   search.c                                                             *
  *                                                                        *
@@ -1342,7 +1342,7 @@ void update_history(filestruct **h, const char *s)
     }
 
     /* Add the new entry to the end. */
-    (*hbot)->data = mallocstrcpy(NULL, s);
+    (*hbot)->data = mallocstrcpy((*hbot)->data, s);
     splice_node(*hbot, make_new_node(*hbot), (*hbot)->next);
     *hbot = (*hbot)->next;
     (*hbot)->data = mallocstrcpy(NULL, "");
