@@ -1,4 +1,4 @@
-/* $Id: text.c,v 1.156 2006/11/10 02:47:11 dolorous Exp $ */
+/* $Id: text.c,v 1.159 2006/12/10 17:57:09 dolorous Exp $ */
 /**************************************************************************
  *   text.c                                                               *
  *                                                                        *
@@ -63,7 +63,7 @@ void do_mark(void)
 }
 #endif /* !NANO_TINY */
 
-/* Delete one character. */
+/* Delete the character under the cursor. */
 void do_delete(void)
 {
     bool do_refresh = FALSE;
@@ -2311,12 +2311,12 @@ void do_spell(void)
 	return;
     }
 
+    i =
 #ifndef NANO_TINY
-    if (openfile->mark_set)
-	i = write_marked_file(temp, temp_file, TRUE, OVERWRITE);
-    else
+	(openfile->mark_set) ? write_marked_file(temp, temp_file, TRUE,
+	OVERWRITE) :
 #endif
-	i = write_file(temp, temp_file, TRUE, OVERWRITE, FALSE);
+	write_file(temp, temp_file, TRUE, OVERWRITE, FALSE);
 
     if (i == -1) {
 	statusbar(_("Error writing temp file: %s"), strerror(errno));
@@ -2446,6 +2446,8 @@ void do_verbatim_input(void)
 	output[i] = (char)kbinput[i];
     output[i] = '\0';
 
+    free(kbinput);
+
     do_output(output, kbinput_len, TRUE);
 
     free(output);
