@@ -1,4 +1,4 @@
-/* $Id: winio.c,v 1.576 2006/11/10 20:13:38 dolorous Exp $ */
+/* $Id: winio.c,v 1.581 2006/12/02 23:39:16 dolorous Exp $ */
 /**************************************************************************
  *   winio.c                                                              *
  *                                                                        *
@@ -484,6 +484,7 @@ int parse_kbinput(WINDOW *win, bool *meta_key, bool *func_key)
 			retval = get_control_kbinput(
 				parse_escape_seq_kbinput(win,
 				*kbinput));
+		    break;
 	    }
     }
 
@@ -662,6 +663,8 @@ int parse_kbinput(WINDOW *win, bool *meta_key, bool *func_key)
     fprintf(stderr, "parse_kbinput(): kbinput = %d, meta_key = %s, func_key = %s, escapes = %d, byte_digits = %d, retval = %d\n", *kbinput, *meta_key ? "TRUE" : "FALSE", *func_key ? "TRUE" : "FALSE", escapes, byte_digits, retval);
 #endif
 
+    free(kbinput);
+
     /* Return the result. */
     return retval;
 }
@@ -1441,9 +1444,12 @@ void unparse_kbinput(char *output, size_t output_len)
 	return;
 
     input = (int *)nmalloc(output_len * sizeof(int));
+
     for (i = 0; i < output_len; i++)
 	input[i] = (int)output[i];
+
     unget_input(input, output_len);
+
     free(input);
 }
 
@@ -1534,6 +1540,8 @@ int *parse_verbatim_kbinput(WINDOW *win, size_t *kbinput_len)
 	/* Put back the first keystroke. */
 	unget_input(kbinput, 1);
 
+    free(kbinput);
+
     /* Get the complete sequence, and save the characters in it as the
      * result. */
     *kbinput_len = get_key_buffer_len();
@@ -2095,8 +2103,9 @@ void titlebar(const char *path)
     if (!newfie) {
 	size_t lenpt = strlenpt(path), start_col;
 
-	/* Don't set dots to TRUE if we have fewer than 8 columns (i.e.
-	 * 1 column for padding, plus 7 columns for a filename). */
+	/* Don't set dots to TRUE if we have fewer than eight columns
+	 * (i.e. one column for padding, plus seven columns for a
+	 * filename). */
 	dots = (space >= 8 && lenpt >= space);
 
 	if (dots) {
@@ -2513,9 +2522,12 @@ void edit_draw(const filestruct *fileptr, const char *converted, int
 		     * expanded location of the end of the match minus
 		     * the expanded location of the beginning of the
 		     * page. */
-		    paintlen = (end_line != fileptr) ? -1 :
-			actual_x(converted, strnlenpt(fileptr->data,
-			endmatch.rm_eo) - start);
+		    if (end_line != fileptr)
+			paintlen = -1;
+		    else
+			paintlen = actual_x(converted,
+				strnlenpt(fileptr->data,
+				endmatch.rm_eo) - start);
 
 		    mvwaddnstr(edit, line, 0, converted, paintlen);
 
@@ -2639,8 +2651,11 @@ void edit_draw(const filestruct *fileptr, const char *converted, int
 	     * Otherwise, paintlen is the expanded location of the end
 	     * of the mark minus the expanded location of the beginning
 	     * of the mark. */
-	    paintlen = (bot_x >= endpos) ? -1 : strnlenpt(fileptr->data,
-		bot_x) - (x_start + start);
+	    if (bot_x >= endpos)
+		paintlen = -1;
+	    else
+		paintlen = strnlenpt(fileptr->data, bot_x) - (x_start +
+			start);
 
 	    /* If x_start is before the beginning of the page, shift
 	     * paintlen x_start characters to compensate, and put
